@@ -36,8 +36,8 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-#include <ntqcstring.h>
-#include <ntqstring.h>
+#include <tqcstring.h>
+#include <tqstring.h>
 
 #include <kurl.h>
 #include <tdeio/slavebase.h>
